<template>
    <v-form-section @submitted="updateProfileInformation">
        <template #title> Profile Information</template>
        <template #description>
            Update your account's profile information and email address.
        </template>
        <template #form>
            <!-- Profile Photo -->
            <div class="col-span-6 sm:col-span-6">
                <div class="flex flex-col items-center justify-center">
                    <!-- Profile Photo File Input -->
                    <input type="file" class="hidden" ref="profile_image" @change="updatePhotoPreview"/>

                    <!-- Current Profile Photo -->
                    <div class="mt-2" v-show="!photoPreview">
                        <v-avatar
                            image-class="h-20 w-20 bg-[#9333ea] text-white"
                            :user="{
                            avatar: bioLinkId.profile_image,
                            name: bioLinkId.title ?? 'New Link',
                            }"
                            :with-name="false"
                            :with-email="false"
                        />
                    </div>

                    <!-- New Profile Photo Preview -->
                    <div class="mt-2" v-show="photoPreview">
                        <span
                            class="block h-20 w-20 rounded-full"
                            :style="
                                'background-size: cover; background-repeat: no-repeat; background-position: center center; background-image: url(\'' +
                                photoPreview +
                                '\');'
                            "
                        >
                        </span>
                    </div>

                    <div class="mt-5 flex items-center justify-center">
                        <PremiumFeatureOverlay :isDisabled="!permissions.user_profile_avatar">
                            <v-secondary-button
                                :disabled="!permissions.user_profile_avatar"
                                class="mr-2"
                                type="button"
                                @click.prevent="selectNewPhoto"
                                small
                            >
                                Select a New Photo
                            </v-secondary-button>
                            <v-danger-button
                                :disabled="!permissions.user_profile_avatar"
                                type="button"
                                @click.prevent="deletePhoto"
                                v-if="bioLinkId.profile_image"
                                small
                            >
                                Remove Photo
                            </v-danger-button>
                        </PremiumFeatureOverlay>
                    </div>
                </div>

                <v-input-error :message="form.errors.photo" class="mt-2"/>
            </div>

            <!-- Username -->
            <div class="col-span-6 sm:col-span-6">
                <v-label for="name" value="Name"/>
                <v-input
                    id="name"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.title"
                    autocomplete="name"
                />
                <v-input-error :message="form.errors.title" class="mt-2"/>
            </div>

            <!-- Name -->
            <div class="col-span-6 sm:col-span-6">
                <PremiumFeatureOverlay :isDisabled="!permissions.use_custom_slug">
                    <v-label for="slug" value="Slug"/>
                    <v-input
                        id="slug"
                        :disabled="!permissions.use_custom_slug"
                        type="text"
                        class="mt-1 block w-full"
                        v-model="form.slug"
                        autocomplete="slug"
                    />
                    <v-input-error :message="form.errors.slug" class="mt-2"/>
                </PremiumFeatureOverlay>
            </div>

            <!-- Email -->
            <!--            <div class="col-span-6 sm:col-span-6">-->
            <!--                <v-label for="email" value="Email" />-->
            <!--                <v-input id="email" type="email" class="mt-1 block w-full" v-model="form.email" />-->
            <!--                <v-input-error :message="form.errors.email" class="mt-2" />-->
            <!--            </div>-->

            <!-- Bio -->
            <div class="col-span-6 sm:col-span-6">
                <v-label for="description" value="Description"/>
                <v-textarea id="description" class="mt-1 block w-full" rows="5" v-model="form.description"></v-textarea>
                <v-input-error :message="form.errors.description" class="mt-2"/>
            </div>
        </template>

        <template #actions>
            <v-action-message :on="form.recentlySuccessful" class="mr-3"> Saved.</v-action-message>

            <PremiumFeatureOverlay :isDisabled="!permissions.use_profile">
                <v-button :class="{ 'opacity-25': form.processing }" :disabled="!permissions.use_profile || form.processing">
                    Save
                </v-button>
            </PremiumFeatureOverlay>
        </template>
    </v-form-section>
</template>

<script>
import VButton from "@/Components/Button";
import VFormSection from "@/Components/FormSection";
import VInput from "@/Components/Input";
import VInputError from "@/Components/InputError";
import VLabel from "@/Components/Label";
import VActionMessage from "@/Components/ActionMessage";
import VSecondaryButton from "@/Components/SecondaryButton";
import VAvatar from "@/Components/Avatar";
import VDangerButton from "@/Components/DangerButton";
import VTextarea from "@/Components/Textarea";
import PremiumFeatureOverlay from "@/Components/PremiumFeatureOverlay.vue";

export default {
    components: {
        PremiumFeatureOverlay,
        VTextarea,
        VDangerButton,
        VAvatar,
        VActionMessage,
        VButton,
        VFormSection,
        VInput,
        VInputError,
        VLabel,
        VSecondaryButton,
    },

    props: ["bioLinkId", "permissions"],

    data() {
        return {
            form: this.$inertia.form({
                _method: "PUT",
                id: this.$props.bioLinkId.id,
                slug: this.$props.bioLinkId.slug,
                title: this.$props.bioLinkId.title,
                description: this.$props.bioLinkId.description,
                profile_image: null,
            }),
            photoPreview: null,
        };
    },

    methods: {
        updateProfileInformation() {
            if (this.$refs.profile_image) {
                this.form.profile_image = this.$refs.profile_image.files[0];
            }
            this.form.post(route("user-profile-information.update", this.$props.bioLinkId), {
                errorBag: "updateProfileInformation",
                preserveScroll: true,
                onSuccess: () => this.clearPhotoFileInput(),
            });
        },

        selectNewPhoto() {
            this.$refs.profile_image.click();
        },

        updatePhotoPreview() {
            const photo = this.$refs.profile_image.files[0];

            if (!photo) return;

            const reader = new FileReader();

            reader.onload = (e) => {
                this.photoPreview = e.target.result;
            };

            reader.readAsDataURL(photo);

            this.updateProfileInformation();
        },

        deletePhoto() {
            this.$inertia.delete(route("user.current-user-photo.destroy", {
                bioLinkId: this.bioLinkId
            }), {
                preserveScroll: true,
                onSuccess: () => {
                    this.photoPreview = null;
                    this.clearPhotoFileInput();
                },
            });
        },

        clearPhotoFileInput() {
            if (this.$refs.profile_image?.value) {
                this.$refs.profile_image.value = null;
            }
        },
    },
};
</script>
